<a name="librelingo_yaml_loader"></a>
# librelingo\_yaml\_loader

Load YAML-based LibreLingo courses in your Python project.

<a name="librelingo_yaml_loader.yaml_loader"></a>
# librelingo\_yaml\_loader.yaml\_loader

<a name="librelingo_yaml_loader.yaml_loader.load_course"></a>
#### load\_course

```python
load_course(path)
```

Load a YAML-based course into a Course() object

